@@ -1,5 +1,4 @@
 from pygame import mixer
-import cv2
 from threading import  Timer
 import os
 from pathlib import  Path
@@ -10,7 +9,6 @@ from pathlib import  Path
 
 
 class sound_manager:
-    __font = cv2.FONT_HERSHEY_COMPLEX_SMALL
     SENSITIVITY_LOW = 8
     SENSITIVITY_MEDIUM = 3
     SENSITIVITY_HIGH = 1
